@@ -17,11 +17,14 @@ class JSONSink(Sink):
     Example configuration::
 
          "args": {
-             'test': {
-                 'frametype': 'dict',
-                 'filename': '%(output)s/%(runid)s/mytestoutput.json',
-                 'params': {}
+             "sink": {
+                 'test': {
+                     'frametype': 'dict',
+                     'filename': '%(output)s/%(runid)s/mytestoutput.json',
+                     'params': {}
+                 }
              }
+         }
     """
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -30,10 +33,12 @@ class JSONSink(Sink):
         self.testdata = {
             'conf': {
                 'args': {
-                    'frame1': {
-                        'frametype': 'dict',
-                        'filename': '%(output)s/%(runid)s/mytestoutput.json',
-                        'params': {}
+                    'sink': {
+                        'frame1': {
+                            'frametype': 'dict',
+                            'filename': '%(output)s/%(runid)s/mytestoutput.json',
+                            'params': {}
+                        }
                     }
                 }
             },
@@ -54,13 +59,19 @@ class JSONSink(Sink):
         Clean when the spec is loaded...
         """
 
-        #=> Args
+        if 'sink' not in args:
+            args = {
+                'sink': args
+            }
+
         args = super().preload_clean_args(args)
 
-        # Sanity check...
-        assert isinstance(args, dict)
+        assert 'sink' in args
+        assert isinstance(args['sink'], dict)
+        assert len(args['sink']) > 0
 
-        for name, detail  in args.items():
+        sink = args['sink']
+        for name, detail  in sink.items():
 
             if (("frametype" not in detail) or
                 (detail['frametype'] != 'dict')):
@@ -108,8 +119,13 @@ class JSONSink(Sink):
         An extra check on the arguments to make sure
         it is consistent with the specification
         """
-        assert isinstance(self.args, dict)
-        for name, detail  in self.args.items():
+        args = self.args
+        assert 'sink' in args
+        assert isinstance(args['sink'], dict)
+        assert len(args['sink']) > 0
+
+        sink = args['sink']
+        for name, detail  in sink.items():
             assert (('frametype' in detail) and (detail['frametype'] == 'dict'))
             assert 'filename' in detail
             assert 'params' in detail
@@ -131,7 +147,9 @@ class JSONSink(Sink):
         args_input = {}
         write_input = {}
         framecls = self.config.get_dataframe('dict')
-        for pattern in self.args:
+
+        sink = self.args['sink']
+        for pattern in sink:
             # The pattern could be precise dataframe name or could be
             # regular expression.
             regex = re.compile('^{}$'.format(pattern))
@@ -155,7 +173,7 @@ class JSONSink(Sink):
                     continue
 
                 # Now construct the output file name
-                filename = self.args[pattern]['filename']
+                filename = sink[pattern]['filename']
                 filename = self.config.get_file(filename,
                                                 create_dir=True,
                                                 extra={
@@ -167,7 +185,7 @@ class JSONSink(Sink):
                     'descriptions': self.collapse_descriptions(detail)
                 }
 
-                params = self.args[pattern].get('params',{})
+                params = sink[pattern].get('params',{})
                 write_input[f] = {
                     'frametype': detail['frametype'],
                     'filename': filename,
@@ -176,7 +194,7 @@ class JSONSink(Sink):
                     'params': params
                 }
 
-                args_input[f] = copy.copy(self.args[pattern])
+                args_input[f] = copy.copy(sink[pattern])
                 args_input[f]['filename'] = filename
 
         framecls.write(args_input, write_input)
@@ -187,7 +205,7 @@ class JSONSink(Sink):
 
             # => Insert columns and tags
             pattern = detail['pattern']
-            detail['params']['tags'] = self.args[pattern]['tags']
+            detail['params']['tags'] = sink[pattern]['tags']
 
             # Incorporate columns, notes and description
             detail['params'].update(extra[name])
