@@ -117,6 +117,10 @@ class SQLExport(Sink):
                 ('frames' not in e)):
                 raise Exception("Each element of the export should be a dictionary with filename, type, and frames")
 
+            if (('replace' in e) and
+                (not isinstance(e['replace'], bool))):
+                raise Exception("replace is a boolean variable")
+
             if  e['type'] != 'sqlite':
                 raise Exception("Only sqlite exports are supported in current version")
 
@@ -162,6 +166,7 @@ class SQLExport(Sink):
                                                     what='enrich_data_dir')
 
             name = e.get('name', os.path.basename(filename))
+            replace = e.get('replace', False)
 
             try:
                 os.makedirs(os.path.dirname(filename))
@@ -186,6 +191,10 @@ class SQLExport(Sink):
 
                         df = frames[f]['df']
 
+                        # Drop existing table if necessary...
+                        if replace:
+                              c.execute(f'DROP TABLE IF EXISTS {f}')
+
                         # => First create the table schema
                         ddl = pd.io.sql.get_schema(df, f)
                         c.execute(ddl) # CREATE table
