@@ -45,6 +45,7 @@ from ..lib import *
 from ..lib.customer import load_customer_assets
 from ..app.flask.render import create_app
 from enrichsdk.tasks import Task
+from enrichsdk.core.res import set_limits
 
 __all__ = ['bootstrap', 'test_transform', 'test_conf',
            'test_task', 'checkenv', 'print_log',
@@ -1817,6 +1818,9 @@ def test_transform(pkgdir, capture=False, context=None):
 
     """
 
+    # Fix memory limits...
+    set_limits()
+
     pkgdir = os.path.abspath(pkgdir)
 
     # Setup logging
